//Listing 2.21 Java code using SAX parser
// XML - A Dsitributed Computing Paradigm - Ajay M R

import org.xml.sax.*;
import org.xml.sax.helpers.*;
import java.io.*;
import java.util.*;
import common.*;


public class SAXSample extends DefaultHandler {

   // The following variable stores the XML string in sort of stack
   private Stack tagStack = new Stack();

   // List of item names stored as Vector
   private Vector items = new Vector();

   // Client name
   private String client;

   // Collecting data in the buffer from
   // the "characters" SAX event.
   private CharArrayWriter contents = new CharArrayWriter();

   // Override methods of the DefaultHandler class
   // to receive of SAX Events.

   public void startElement( String namespaceURI,
               String localName,
              String qName,
              Attributes attr ) throws SAXException {

      contents.reset();

      // push the tag name in the stack
      tagStack.push( localName );

      // display the current path that has been found...
      System.out.println( "Path: [" + getTagPath() + "]" );

   }

   public void endElement( String namespaceURI,
               String localName,
              String qName ) throws SAXException {

      if ( getTagPath().equals( "/Order/Customer/Name" ) ) {
         client = contents.toString().trim();
      }
      else if ( getTagPath().equals( "/Order/Items/Item/Name" ) ) {
         items.addElement( contents.toString().trim() );
      }

      // clean the stack
      tagStack.pop();
   }


   public void characters( char[] ch, int start, int length )
                  throws SAXException {
      // collect the contents into a buffer.
      contents.write( ch, start, length );

   }




   // Build the path string from the current stack 
   private String getTagPath( ){

      //  construct path string
      String buffer = "";
      Enumeration e = tagStack.elements();
      while( e.hasMoreElements()){
               buffer  = buffer + "/" + (String) e.nextElement();
      }
      return buffer;
   }


   public Vector getItems() {
           return items;
   }

   public String getClientName() {
         return client;
   }

   public static void main( String[] argv ){

      System.out.println( "SAXExample:" );
      try {

         // Start using SAX 2 parser
         XMLReader xr = XMLReaderFactory.createXMLReader();

         // Set ContentHandler
         SAXExample ex1 = new SAXExample();
         xr.setContentHandler( ex1 );

         System.out.println();
         System.out.println("Tag Paths:");

         // File parsing
         xr.parse( new InputSource(new FileReader( "Sample.xml" )) );

         System.out.println();
         System.out.println("Names:");

         // Display Client
         System.out.println( "Client Name: " + ex1.getClientName() );


         // Display all item names 
         System.out.println( "Order Items list: " );
         String itemName;
         Vector items = ex1.getItems();
         Enumeration e = items.elements();
         while( e.hasMoreElements()){
                   itemName = (String) e.nextElement();
            System.out.println( itemName );
         }


      }catch ( Exception e )  {
         System.out.println( "ERROR: Stack Trace: ");
         e.printStackTrace();
      }


   }

}
