//Background: For unicast discovery, the device must know the IP address and the port number where the lookup service is running. 
// The Jini Framework uses the net.jini.core.discovery.LookupLocator class to specify the pre-known IP and Port using a string called Jini URL. 

//The Jini URL format is jini://MachineIP:PORTNO. After creating a LookupLocator with required Jini URL, we just need to call its getRegistrar() //function which give you a lookup service object representation known as a ServiceRegistrar. The rest of the operations on the lookup service can//be done through the ServiceRegistrar object. All the Unicast discovery protocol fundamentals are encapsulated within the LookupLocator class

//In the code below....
//The LookupLocator object is created based on the Jini URL string passed. If the Jini URL string does not have a port number mentioned, 
//a default port number of 4160 is assumed. 

import net.jini.core.discovery.LookupLocator;
import net.jini.core.lookup.ServiceRegistrar;
// XML - A Distributed Computing Paradigm - Ajay M R

	public class UnicastDiscovery{
	
		String JiniURL;
		public UnicastDiscovery(String jiniURL){
			JiniURL = jiniURL;
		}
	
		public UnicastDiscovery(String IP , int port){
			JiniURL = "jini://"+IP+port;
		}
		public ServiceRegistrar startUnicastDiscovery()throws Exception{
			// Instantiate a LookupLocator object for the lookup service indicated 
			// Uses the IP and port number passed in. (If no port number 
			// is specified, the default port of 4160 will be used.) 
			LookupLocator lookupLocator = new LookupLocator(JiniURL);
	
			// Invoke getRegistrar() on the LookupLocator to perform a 
			// unicast discovery on the lookup service. The lookup service is indicated by the 
			// host and port number passed to the constructor. The result is a reference to the 
			// registrar object representing the lookup service. 
			ServiceRegistrar registrar = lookupLocator.getRegistrar(); 
			return registrar;
		}
		
		public static void main(String args[]){
			UnicastDiscovery ud = null;
						
			if(args.length < 1){
				ud = new UnicastDiscovery("jini://127.0.0.1:4160");
			}
			else
			{
				ud= new UnicastDiscovery(args[0]);
			}
			try{
				ServiceRegistrar reg = ud.startUnicastDiscovery();
				System.out.println("The Jini ServiceID :"+reg.getServiceID());
			}catch(Exception e){
				System.out.println("Error :"+e);
				e.printStackTrace();
			}
		}
	}