/* Static Model */
package sams;


/* Aids Query engine to invoke the respective adapters dynamically at runtime. */
public interface AdapterBinderInterface
{
	/* Set binding file path. Each binding entry is stored in the XML map file. The file maps the method names and the adapter registered in the system. Once the message is passed from query engine to binder, the binder uses this binding file to arrive at exact adapter to be invoked. */
	public abstract boolean SetBindingFile(char BindFilePath);
	/* Invoke respective adapter dynamically as per map entry in binding file. */
	public abstract boolean InvokeAdapter();
	/* Set debug level specifier. Specifies the debug level for the log entries. A special case used with this interface, as adapter binder rely on binding file data and dynamically interact with the adapters. */
	public abstract int SetDebug(int DebugLevel);
	/* Refresh the bindings - this would cause the binding file to be read again and used for adapter settings. */
	public abstract boolean RefreshBinding();
	/* Initialize the adapter binder would usually read the configuration file, the bindings map file. This way it would keep a memory image, in form on XML document isntance, of the bind-able adapters existing in the system. */
	public abstract boolean InitializeAdapterBinderInterface();
	/* Set reference to system wide error queue to dump any possible errors. */
	public abstract boolean SetErrorQueueReference();

}
/* END CLASS DEFINITION AdapterBinderInterface */
