/* Static Model */
package sams;


import sams.XMLDocumentInstance;
/* Error queue is the database log of all system errors. For all the errors occuring in the system this interface provides a way to store them, so that the resultant process could pick up and find it whenever required. Each error is referenced with the associated token issued, which is passed to the calling process. */
public interface ErrorQueueInterface
{
	/* Initialize the error queue. This operation sets the queue size and possible data mechanism to save the errors. This routine would use the configuration file to read this initial settings. */
	public abstract boolean InitializeQueue(char QueueFilePath,
										 char QueueFileName);
	/* Calling this method would result in current error queue written to a disk file. The file format would represent a XML stream with all the current messages in queue.  */
	public abstract boolean PersistQueue(char PersistFilePath,
									  char PersistFileName);
	/* This method would cause the error queue to be rebuilt from the persistent store, which is an XML disk file representing error messages on queue. */
	public abstract boolean RefreshQueue(boolean ReadFile,
									  boolean ReadFromPersistFileStore);
	/* Gets the current errors accounted in the queue. */
	public abstract double GetCurrentQueueCount();
	/* Dumps the error message in queue. The same generic XML packet format is used to represent the error message. The error is parsed and re-presented in varying XML format for storage. */
	public abstract double PutInQueue(XMLDocumentInstance ErrorPacket);
	/* Returns the error as generic XML message packet. The error is referenced by the token# passed as parameter. */
	public abstract XMLDocumentInstance GetFromQueue(double ErrorToken,
												  char OperationMethod);
	/* This method would delete the entire error queue. The method requires a authentication key to perform the operation. */
	public abstract boolean DeleteQueue(double SecurityKey);

}
/* END CLASS DEFINITION ErrorQueueInterface */
