/* Static Model */
package sams;


import sams.DatabaseManagerInterface;
import sams.ErrorQueueInterface;
import sams.LogInterface;
import sams.RPCCommunicationInterface;
import sams.SOAPCommunicationInterface;
import sams.SecurityInterface;
import sams.TrackingInterface;
import sams.XMLDocumentInstance;
/* Central Processor is core to the entire system and executes all message task packets. It interacts with the queue manager and executes the mesages sequentially. The execution of central processor could be controlled by thread behaviour, as it spawns number of threads to attend to queue manager and get the task.  */
public interface CentralProcessorInterface
{
	/* Initializes major or all system initialization routines, here it would refer to configuration settings in file. */
	public abstract boolean InitializeProcessor();
	/* As to attend and execute each process we propose the central processor to spawn a new Thread for every process to be attended. Once the attendant thread is created it would be given the task message packet and would exists till the process is complete. This setting would set the maximum number of threads allowed to be spawned in the system. */
	public abstract boolean SetMaxProcessesInParallel(int MaxProcesses);
	/* Would restart the processor by soft-trigger method, after it has been stopped. */
	public abstract boolean StartProcessor();
	/* Stops the current processing actions. The active threads would be allowed to complete the operations before this actions takes effect. Also, the processor could be start using StartProcessor method, as this method does not kill the initialization settings. */
	public abstract boolean StopProcessor();
	/* Between execution of two processes by the processor, depending on threads and other related modules responses it would be necessary to set the intermediate delay. This delay would also take care of the asynchronous nature of FTP interface in the legacy system. This delay would be used for fine tuning the system after deployment in real world environment. */
	public abstract boolean SetIntermediateDelay(double DelayTime);
	/* Synchronous gateway method for the central processor. This method allows the request to be routed directly to processor without queue interface. The central processor would attend to such request as priority tasks and spawn a high priority thread for attending those. */
	public abstract XMLDocumentInstance ProcessRequestDirect(XMLDocumentInstance Request);
	/* Inquiry method to know the request status, typically used for asynchronous communications. The request Token# is used for refernence. Further the return type would be an XML document with various return tag values. */
	public abstract XMLDocumentInstance InquireOnRequestStatus(double TokenNumber);
	/* This method is to allow third party systems to place request in queue using central processor interface. */
	public abstract XMLDocumentInstance ProcessRequest(XMLDocumentInstance RequestPacket);
	/* Dumps the current processing attributes in a XML file. The attributes would include the current message token# for IN and OUT queue. The last message attended time stamp and related stuff. */
	public abstract boolean PersistProcesses(char FilePath,
										  char FileName);
	/* Same as Start processor method, except that it directs the central processor to read the data from persistant store and resume from where it was stopped before. For this method to work, PersistProcess should be called before StopProcessor. */
	public abstract boolean ResumeFromPersist();
	/* Returns the current system wide log interface to used. */
	public abstract LogInterface GetLogInterfaceReference();
	/* Returns the current system wide RPC interface to used. */
	public abstract RPCCommunicationInterface GetRPCComReference();
	/* Returns the current system wide SOAP interface to used. */
	public abstract SOAPCommunicationInterface GetSOAPComReference();
	/* Returns the current system wide Data Manager interface to used. */
	public abstract DatabaseManagerInterface GetDataManagerReference();
	/* Returns the current system wide Security interface to used. */
	public abstract SecurityInterface GetSecurityReference();
	/* Returns the current system wide Tracking interface to used. */
	public abstract TrackingInterface GetTrackingReference();
	/* Returns the current system wide Error Queue interface to used. */
	public abstract ErrorQueueInterface GetErrorQueueReference();

}
/* END CLASS DEFINITION CentralProcessorInterface */
