/* Static Model */
package sams;


import sams.XMLDocumentInstance;
/* This acts like a database gateway. It allows various processes to interact with the Interface database. Though the interface system would have a low-end database this service would be useful to interact with the databases when they grow big. Further, the data manager has capability ot use files as storage areas. */
public interface DatabaseManagerInterface
{
	/* Initialize Data Management Services, this also triggers the Connection Pool Initialization. The database attributes could be passed by secondary program through SetXXX methods, but usually this routine would refer to those from the configuration file. */
	public abstract boolean InitializeDataManager();
	/* Sets the minimal parameters to interface with the database. This includes DSN name and authentication details. */
	public abstract boolean SetDatabaseParameters(char DatabaseDSN,
											   char Username,
											   char Password,
											   char FileDatabasePath,
											   double MaxFileDatabaseSize);
	/* Sets the database type. As for initial usage it would be possible to use a simple text file with data in XML format for low install overhead. */
	public abstract boolean SetDatabaseType(char DatabaseType);
	/* Allows the processes to insert data in the database. Accepts the SQL embedded in XML format. The database interface needs to reformat the query for storing the same in file format. */
	public abstract boolean InsertXMLStream(XMLDocumentInstance XMLQueryStream);
	/* Allows the processes to update data in the database. Accepts the SQL embedded in XML format. The database interface needs to reformat the query for storing the same in file format. */
	public abstract boolean UpdateXMLStream(XMLDocumentInstance XMLQueryStream);
	/* Allows the processes to delete data in the database. Accepts the SQL embedded in XML format. The database interface needs to reformat the query for storing the same in file format. */
	public abstract boolean DeleteXMLStream(XMLDocumentInstance XMLQueryStream);
	/* Allows the processes to select the data from the database. Accepts the SQL embedded in XML format. The database interface returns the result set in XML format. */
	public abstract char SelectAsXMLStream(XMLDocumentInstance XMLQueryStream);
	/* Preliminary setting for number of concurrent conenctions to be allowed. This would limit the threads created for attending client connection requests at later stages. */
	public abstract boolean MaxActiveConnections(int NumberOfEconnections);
	/* Sets Connection Pool Manager */
	public abstract boolean SetConnectionPoolManager();
	/* Returns the reference to the conenction pool created. Could be used by secondary database manager or database gateway services. */
	public abstract void GetConnectionPoolReference();
	/* Returns the connection object to be used, from connection pool. */
	public abstract void GetConnectionForUse();
	/* Shuts down the services. But the services are still initialized and could be still started. */
	public abstract boolean ShutDownDataManagerServices();
	/* Starts the previously shut down database manager services. If the services are not initialized then an attempt to start them would return an error. */
	public abstract boolean StartDataManagerServices();

}
/* END CLASS DEFINITION DatabaseManagerInterface */
